nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

SwPadCtlPadPmicStbyReq

Struct SwPadCtlPadPmicStbyReq 

#[repr(transparent)]
pub struct SwPadCtlPadPmicStbyReq(pub u32);
SW_PAD_CTL_PAD_PMIC_STBY_REQ SW PAD Control Register

Tuple Fields

0: u32

Implementations

Source

impl SwPadCtlPadPmicStbyReq

pub const fn sre(&self) -> SwPadCtlPadPmicStbyReqSre

Slew Rate Field

pub const fn set_sre(&mut self, val: SwPadCtlPadPmicStbyReqSre)

Slew Rate Field

pub const fn dse(&self) -> SwPadCtlPadPmicStbyReqDse

Drive Strength Field

pub const fn set_dse(&mut self, val: SwPadCtlPadPmicStbyReqDse)

Drive Strength Field

pub const fn speed(&self) -> SwPadCtlPadPmicStbyReqSpeed

Speed Field

pub const fn set_speed(&mut self, val: SwPadCtlPadPmicStbyReqSpeed)

Speed Field

pub const fn ode(&self) -> SwPadCtlPadPmicStbyReqOde

Open Drain Enable Field

pub const fn set_ode(&mut self, val: SwPadCtlPadPmicStbyReqOde)

Open Drain Enable Field

pub const fn pke(&self) -> SwPadCtlPadPmicStbyReqPke

Pull / Keep Enable Field

pub const fn set_pke(&mut self, val: SwPadCtlPadPmicStbyReqPke)

Pull / Keep Enable Field

pub const fn pue(&self) -> SwPadCtlPadPmicStbyReqPue

Pull / Keep Select Field Control signal to enable internal pull-up/down resistors or pad keeper functionality.

pub const fn set_pue(&mut self, val: SwPadCtlPadPmicStbyReqPue)

Pull / Keep Select Field Control signal to enable internal pull-up/down resistors or pad keeper functionality.

pub const fn pus(&self) -> SwPadCtlPadPmicStbyReqPus

Pull Up / Down Config. Field Controls signals to select pull-up or pull-down internal resistance strength.

pub const fn set_pus(&mut self, val: SwPadCtlPadPmicStbyReqPus)

Pull Up / Down Config. Field Controls signals to select pull-up or pull-down internal resistance strength.

pub const fn hys(&self) -> SwPadCtlPadPmicStbyReqHys

Hyst. Enable Field

pub const fn set_hys(&mut self, val: SwPadCtlPadPmicStbyReqHys)

Hyst. Enable Field